@@ -1,5 +1,5 @@
 package Whelk::Wrapper::Simple;
-$Whelk::Wrapper::Simple::VERSION = '1.01';
+$Whelk::Wrapper::Simple::VERSION = '1.02';
 use Kelp::Base 'Whelk::Wrapper';
 use Kelp::Exception;
 
@@ -23,9 +23,9 @@ sub build_response_schemas
 	my $schema = $endpoint->response;
 	my $schemas = $endpoint->response_schemas;
 
-	$schemas->{200} = $schema;
+	$schemas->{$endpoint->response_code} = $schema;
 
-	$schemas->{500} = $schemas->{400} = Whelk::Schema->get_or_build(
+	$schemas->{'5XX'} = $schemas->{'4XX'} = Whelk::Schema->get_or_build(
 		api_error_simple => {
 			type => 'object',
 			properties => {
